@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -35,7 +34,7 @@ import json
 import logging
 from datetime import datetime
 from socket import gethostname
-from typing import Dict, List  # noqa: F401
+from typing import Self
 
 from univention.config_registry import ConfigRegistry
 
@@ -46,8 +45,7 @@ ucr.load()
 LOG_FILE = '/var/log/univention/admindiary.log'
 
 
-def get_events_to_reject():
-    # type: () -> List[str]
+def get_events_to_reject() -> list[str]:
     ucrv = 'admin/diary/reject'
     blocked_events = ucr.get(ucrv)
     if blocked_events:
@@ -58,16 +56,14 @@ def get_events_to_reject():
 class _ShortNameFormatter(logging.Formatter):
     shorten = 'univention.admindiary'
 
-    def format(self, record):
-        # type: (logging.LogRecord) -> str
+    def format(self, record: logging.LogRecord) -> str:
         record.short_name = record.name
         if record.short_name.startswith('%s.' % self.shorten):
             record.short_name = record.short_name[len(self.shorten) + 1:]
-        return super(_ShortNameFormatter, self).format(record)
+        return super().format(record)
 
 
-def _setup_logger():
-    # type: () -> logging.Logger
+def _setup_logger() -> logging.Logger:
     base_logger = logging.getLogger('univention.admindiary')
     if not _setup_logger._setup:
         base_logger.setLevel(logging.INFO)
@@ -87,8 +83,7 @@ def _setup_logger():
 _setup_logger._setup = False
 
 
-def get_logger(name):
-    # type: (str) -> logging.Logger
+def get_logger(name: str) -> logging.Logger:
     base_logger = _setup_logger()
     logger = base_logger.getChild(name)
     log_level = ucr.get('admin/diary/logging/%s' % name)
@@ -101,9 +96,8 @@ def get_logger(name):
     return logger
 
 
-class DiaryEntry(object):
-    def __init__(self, username, message, args, tags, context_id, event_name):
-        # type: (str, str, Dict[str, str], List[str], str, str) -> None
+class DiaryEntry:
+    def __init__(self, username: str, message: str, args: dict[str, str], tags: list[str], context_id: str, event_name: str) -> None:
         self.username = username
         self.hostname = gethostname()
         self.message = message
@@ -113,8 +107,7 @@ class DiaryEntry(object):
         self.context_id = context_id
         self.event_name = event_name
 
-    def assert_types(self):
-        # type: () -> None
+    def assert_types(self) -> None:
         if not isinstance(self.username, str):
             raise TypeError('DiaryEntry() argument "username" has to be "string", but is: %s (%s)' % (type(self.username), self.username))
         if not isinstance(self.hostname, str):
@@ -138,8 +131,7 @@ class DiaryEntry(object):
         if not isinstance(self.event_name, str):
             raise TypeError('DiaryEntry() argument "event" name has to be "string", but is: %s (%s)' % (type(self.event_name), self.event_name))
 
-    def to_json(self):
-        # type: () -> str
+    def to_json(self) -> str:
         attrs = {
             'username': self.username,
             'hostname': self.hostname,
@@ -154,8 +146,7 @@ class DiaryEntry(object):
         return json.dumps(attrs)
 
     @classmethod
-    def from_json(cls, body):
-        # type: (str) -> DiaryEntry
+    def from_json(cls, body: str) -> Self:
         json_body = json.loads(body)
         entry = cls(json_body['username'], json_body['message'], json_body['args'], json_body['tags'], json_body['context_id'], json_body['event'])
         entry.timestamp = datetime.strptime(json_body['timestamp'], '%Y-%m-%d %H:%M:%S')
