@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -31,10 +30,10 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
+from collections.abc import Callable, Iterable, Iterator  # noqa: F401
 from contextlib import contextmanager
 from datetime import datetime  # noqa: F401
 from functools import partial
-from typing import Any, Callable, Dict, Iterable, Iterator, List, Optional, Set, Tuple  # noqa: F401
 
 import sqlalchemy
 from sqlalchemy import Boolean, Column, DateTime, ForeignKey, Integer, Sequence, String, Table, Text, and_, func, or_
@@ -205,7 +204,7 @@ class Arg(Base):
     entry = relationship('Entry')
 
 
-class Client(object):
+class Client:
     def __init__(self, version, session):
         # type: (int, sqlalchemy.Session) -> None
         self.version = version
@@ -330,10 +329,10 @@ class Client(object):
             # form filters array
             filters = [
                 or_(
-                    Entry.message.ilike('%{}%'.format(pat)),
+                    Entry.message.ilike(f'%{pat}%'),
                     and_(
                         EventMessage.locale == locale,
-                        EventMessage.message.ilike('%{}%'.format(pat)),
+                        EventMessage.message.ilike(f'%{pat}%'),
                     ),
                     Entry.args.any(Arg.value == pat),
                 )
