@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -34,10 +33,11 @@
 import logging
 import os
 import uuid
+from collections.abc import Callable
 from functools import partial, wraps
 from getpass import getuser
 from logging.handlers import SysLogHandler
-from typing import Any, Callable, Dict, List, Optional, TypeVar  # noqa: F401
+from typing import Any, TypeVar
 
 from univention.admindiary import DiaryEntry, get_events_to_reject, get_logger
 from univention.admindiary.events import DiaryEvent
@@ -62,7 +62,7 @@ def exceptionlogging(f):
     return wrapper  # type: ignore
 
 
-class RsyslogEmitter(object):
+class RsyslogEmitter:
     def __init__(self):
         # type: () -> None
         self.handler = None  # type: Optional[SysLogHandler]
