@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Univention Management Console
 #  module: manages system services
@@ -104,7 +103,7 @@ class Instance(Base):
                 hints.append(_('Is %s allowed to connect to the database service on %s?') % (ucr.get('hostname'), db_url.host))
             # hints.append(_('Did the system set up the database? If not, run /usr/share/univention-admin-diary/create-database'))
             raise umcm.UMC_Error('\n'.join(hints), status=500)
-        return super(Instance, self).error_handling(exc, etype, etraceback)
+        return super().error_handling(exc, etype, etraceback)
 
     @simple_response
     def options(self):
